from django.utils.translation import gettext_lazy as _

from django_filters import FilterSet
from material import Layout, Row

from aleksis.core.filters import MultipleCharFilter

from .models import EventRegistration, FeedbackAspect, Voucher


class EventRegistrationFilter(FilterSet):
    class Meta:
        model = EventRegistration
        fields = ["person", "event", "accept_sepa", "date_registred"]

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)

        self.form.layout = Layout(
            Row("person", "event"),
            Row("accept_sepa", "date_registred"),
        )


class VoucherFilter(FilterSet):
    event = MultipleCharFilter(
        [
            "event__short_name__icontains",
        ],
        label=_("Search by event"),
    )

    name = MultipleCharFilter(
        [
            "person__first_name__icontains",
            "person__last_name__icontains",
        ],
        label=_("Search by name"),
    )

    class Meta:
        model = Voucher
        fields = []

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)

        self.form.layout = Layout(Row("event", "name"))


class FeedbackAspectsFilter(FilterSet):
    class Meta:
        model = FeedbackAspect
        fields = ["aspect"]
